![DandeLiion_logo](https://simulation.dandeliion.com/static/dl_logo.png)

#

<div align="center">

[![ci-testing](https://github.com/dandeliion-team/dandeliion-client/actions/workflows/ci_testing.yml/badge.svg?branch=master)](https://github.com/dandeliion-team/dandeliion-client/actions/workflows/ci_testing.yml)
[![documentation](https://github.com/dandeliion-team/dandeliion-client/actions/workflows/documentation.yml/badge.svg?branch=master&action=push)](https://dandeliion-team.github.io/dandeliion-client  )
[![release](https://img.shields.io/github/v/release/dandeliion-team/dandeliion-client?color=yellow)](https://github.com/dandeliion-team/dandeliion-client/releases)
[![OpenSSF Scorecard](https://api.scorecard.dev/projects/github.com/dandeliion-team/dandeliion-client/badge)](https://scorecard.dev/viewer/?uri=github.com/dandeliion-team/dandeliion-client)

</div>

# DandeLiion client

The DandeLiion client is a client software written in Python to submit/run DandeLiion simulations on a remote server and to retrieve simulation results.

## Documentation, examples, and CHANGELOG

- Link to auto-generated documentation: [https://dandeliion-team.github.io/dandeliion-client/index.html](https://dandeliion-team.github.io/dandeliion-client/index.html).
- Ready to use examples are given in the [examples](https://github.com/dandeliion-team/dandeliion-client/tree/master/examples) directory of this repository.
- All notable user-facing changes to this project are documented in the [CHANGELOG](https://github.com/dandeliion-team/dandeliion-client/blob/master/CHANGELOG.md).
